import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:flutter_test/flutter_test.dart';

import 'utils.dart';

final intProvider = StateProvider<int>((_) => 13); // <1>
final watchProvider = Provider<int>((ref) => ref.watch(intProvider));

void main() {
  test('doit écouter un état', () {
    const defaultValue = -1;

    // given:
    final container = createContainer();

    var intValue = defaultValue; // <2>
    container.listen<int>(intProvider, (_, next) => intValue = next);

    var watchValue = defaultValue;
    container.listen<int>(watchProvider, (_, next) => watchValue = next);

    // expect:
    expect(intValue, equals(defaultValue)); // <3>
    expect(watchValue, equals(defaultValue));

    // when:
    container.read(intProvider.notifier).state = 42; // <4>

    // then:
    expect(intValue, equals(42)); // <5>
    expect(watchValue, equals(defaultValue));

    // when:
    container.read(watchProvider); // <6>

    // then:
    expect(intValue, equals(42)); // <7>
    expect(watchValue, equals(42));
  });
}
