import 'package:flutter_test/flutter_test.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';

import 'utils.dart';

final intProvider = StateProvider<int>((ref) => 13); // <1>

final incrementProvider = StateNotifierProvider<IncrementNotifier, int>(
  (ref) => IncrementNotifier(ref.watch(intProvider)),
);

class IncrementNotifier extends StateNotifier<int> {
  IncrementNotifier(int value) : super(value);

  void increment() { // <2>
    state++;
  }
}

void main() {
  test('doit incrémenter un état', () {
    // given:
    final container = createContainer();

    // expect:
    expect(container.read(incrementProvider), equals(13)); // <3>

    // when:
    container.read(incrementProvider.notifier).increment(); // <4>

    // then:
    expect(container.read(incrementProvider), equals(14)); // <5>

    // when:
    container.read(intProvider.notifier).state = 42; // <6>

    // then:
    expect(container.read(incrementProvider), equals(42)); // <7>
  });
}
