import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:flutter_test/flutter_test.dart';

import 'utils.dart';

const duration = Duration(milliseconds: 100);

final asyncIntProvider = StreamProvider<int>( // <1>
  (ref) async* {
    await Future.delayed(duration);
    yield 13;

    await Future.delayed(duration);
    throw Error();
  },
);

void main() {
  test('doit consommer une stream', () async {
    // given:
    final container = createContainer();

    // expect:
    expect(container.read(asyncIntProvider), equals(const AsyncValue<int>.loading())); // <2>

    // when:
    await Future.delayed(duration + const Duration(milliseconds: 50)); // <3>

    // then:
    expect(container.read(asyncIntProvider), equals(const AsyncValue.data(13))); // <4>

    // when:
    await Future.delayed(duration); // <5>

    // then:
    expect(container.read(asyncIntProvider), isInstanceOf<AsyncError>()); // <6>
  });
}
